{% extends "sphinx_rtd_theme/layout.html" %}

{% set css_files = css_files + ["_static/css/explore.css"] %}
{% set css_files = css_files + ["_static/css/nbsphinx.css"] %}

{% set script_files = script_files + ["_static/js/custom.js"] %}

{% block extrahead %}
  <link rel="shortcut icon" href="{{ pathto('_static/images/favicon.ico', 1) }}"/>
  {# SOCIAL GRAPH #}
  <meta name="Description" content="{{ title|striptags|e }}">
  <meta property="og:description" content="{{ title|striptags|e }}">
  <meta name="twitter:description" content="{{ title|striptags|e }}" />
  <meta property="og:title" content="{{ docstitle }} - {{ title|striptags|e }}">
  <meta property="og:image" content="https://github.com/dask.png">
  <meta property="og:image:secure_url" content="https://github.com/dask.png" />
  <meta property="og:image:type" content="image/png" />
  <meta property="og:image:width" content="380" />
  <meta property="og:image:height" content="380" />
  <meta property="og:url" content="{{ theme_canonical_url }}{{ pagename }}.html">
  <meta property="og:site_name" content="{{ docstitle }}">

  <meta name="twitter:site" content="https://dask.org" />
  <meta name="twitter:creator" content="@dask_dev" />
  <meta name="twitter:card" content="summary">
  <meta name="twitter:image" content="https://github.com/dask.png" />
  <meta name="twitter:image:alt" content="{{ docstitle }}">

{% endblock %}

  {% block extrabody %}
    <nav id="explore-links">
        <a href="https://docs.dask.org/">
        <img class="caption" src="{{ pathto('_static/images/dask-horizontal-white.svg', 1) }}"/>
        </a>

        <ul>
        <li>
            <a>Get Started</a>
            <ul>
            <li><a href="https://docs.dask.org/en/latest/install.html"> Install </a></li>
            <li><a href="https://examples.dask.org"> Examples </a></li>
            <li><a href="https://github.com/dask/dask-tutorial"> Tutorial </a></li>
            <li><a href="https://docs.dask.org/en/latest/why.html"> Why Dask? </a></li>
            <li><a href="https://stories.dask.org/en/latest"> Use Cases </a></li>
            <li><a href="https://www.youtube.com/watch?v=RA_2qdipVng&list=PLRtz5iA93T4PQvWuoMnIyEIz1fXiJ5Pri"> Talks </a></li>
            <li><a href="https://mybinder.org/v2/gh/dask/dask-examples/main?urlpath=lab"> Try Online </a></li>
            <li><a href="https://dask.org/slides"> Slides </a></li>
            </ul>
        </li>

        <li>
            <a href="">Algorithms</a>
            <ul>
            <li><a href="https://docs.dask.org/en/latest/array.html">Arrays</a></li>
            <li><a href="https://docs.dask.org/en/latest/dataframe.html">Dataframes</a></li>
            <li><a href="https://docs.dask.org/en/latest/bag.html">Bags</a></li>
            <li><a href="https://docs.dask.org/en/latest/delayed.html">Delayed (custom)</a></li>
            <li><a href="https://docs.dask.org/en/latest/futures.html">Futures (real-time)</a></li>
            <li><a href="http://ml.dask.org">Machine Learning</a></li>
            <li><a href="https://xarray.pydata.org/en/latest/">XArray</a></li>
            </ul>
        </li>

        <li>
            <a href="https://docs.dask.org/en/latest/setup.html">Setup</a>
            <ul>
            <li><a href="https://docs.dask.org/en/latest/setup/single-machine.html"> Local </a></li>
            <li><a href="https://docs.dask.org/en/latest/setup/cloud.html"> Cloud </a></li>
            <li><a href="https://docs.dask.org/en/latest/setup/hpc.html"> HPC </a></li>
            <li><a href="https://kubernetes.dask.org/en/latest/"> Kubernetes </a></li>
            <li><a href="https://yarn.dask.org/en/latest/"> Hadoop / Yarn </a></li>
            </ul>
        </li>

        <li>
            <a>Community</a>
            <ul>
            <li><a href="http://docs.dask.org/en/latest/support.html">Ask for Help</a></li>
            <li><a href="https://github.com/dask">Github</a></li>
            <li><a href="https://stackoverflow.com/questions/tagged/dask">Stack Overflow</a></li>
            <li><a href="https://twitter.com/dask_dev">Twitter</a></li>
            <li><a href="https://blog.dask.org/"> Developer Blog </a></li>
            <li><a href="https://youtube.com/c/dask-dev"> YouTube Channel </a></li>
            <li><a href="https://join.slack.com/t/dask/shared_invite/zt-mfmh7quc-nIrXL6ocgiUH2haLYA914g"> Slack </a></li>
            </ul>
        </li>
        </ul>

    </nav>
  {% endblock %}
