.wy-nav-side {
  padding-top: 50px;
  padding-bottom: 0rem;
}

.wy-nav-content {
  margin-top: 50px;
}

#explore-links {
  position: fixed;
  top: 0;
  left: 0;
  right: 0;
  z-index: 300;
  height: 50px;
  line-height: 50px;
  text-align: center;
  background-color: #1a1a1a;
  color: #ECB172;
  display: flex;
}

#explore-links .caption {
  flex: 0;
  width: 300px;
  max-height: 100%;
  padding: 5px;
}

#explore-links a {
  color: #ECB172;
}

#explore-links a:hover {
  background-color: #343131;
}

@media (max-width: 768px) {
  #explore-links {
    display: none;
  }
}

#explore-links ul { /* all lists... */
  display: flex;
  flex: 1;
  color: #ECB172;
  transition: .3s;

}

#explore-links li { /* all list items... */
  flex: 1;
  position: relative; /* set the origin for child boxes to be positioned from */
  transition: .3s;
  text-align: left;
  max-width: 12rem;
}

#explore-links ul li a {
  padding-left: 1rem;
  display: block;
  height: 100%;
}

#explore-links ul ul { /* lists within lists... */
  left: 0; /* align them to the left of the parent list item  - necessary for some older browsers */
  top: 100%; /* align them to the bottom of the parent list item - again only necessary for older browsers */
  display: none; /* hide 'em */
  color: #ECB172;
  background-color: #1a1a1a;
}

#explore-links li:hover ul { /* when list items are hovered over, do this to lists contained within them... */
  display: block; /* show 'em */
}

#explore-links ul li:hover { /* when list items are hovered over, do this to lists contained within them... */
  background-color: #343131;
}
