/* Turn off In/Out prompts */
div.nbinput div.prompt, div.nboutput div.prompt {
  display: none;
}

.rst-content pre.literal-block div[class^='highlight'], .rst-content div[class^='highlight'] div[class^='highlight'] {
  background: none;
}

.output_area table {
  margin-left: 0;
  margin-right: 0;
  margin-top: 1em;
  border: none;
  border-collapse: collapse;
  border-spacing: 0;
  color: black;
  table-layout: fixed;
}

.output_area thead {
  border-bottom: 1px solid black;
  vertical-align: bottom;
}

.output_area tbody tr:nth-child(2n+1) {
  background: #f5f5f5;
}

.output_area tr, .output_area th, .output_area td {
  text-align: right;
  vertical-align: middle;
  padding: 0.5em 0.5em;
  line-height: normal;
  white-space: normal;
  max-width: none;
  border: none;
}
