@import url("theme.css");

html {
  /* Offset href links for header.
   * See: https://css-tricks.com/fixed-headers-on-page-links-and-overlapping-content-oh-my/ */
  scroll-padding-top: 50px
}

.rst-content h1,h2,h3,h4,h5{
  font-family: 'Garamond', 'Georgia', serif;
  font-weight: normal;
}

.rst-content h1 {
  font-size: 240%;
}

.rst-content h2 {
  font-size: 180%;
}

.rst-content h3 {
  font-size: 160%;
}

.wy-menu-vertical li ul li a,
.wy-menu-vertical li.current a,
.wy-menu-vertical a {
  color: #ECB172;
}

.wy-menu-vertical li.toctree-l2.current>a:hover,
.wy-menu-vertical li.toctree-l2.current li.toctree-l3>a:hover,
.wy-menu-vertical li.toctree-l3.current li.toctree-l4>a:hover,
.wy-menu-vertical li.current a:hover {
  background: #404040;
  color: #ECB172;
}

.wy-menu-vertical a:hover {
  background: #303030;
}

.wy-side-nav-search>a img.logo,
.wy-side-nav-search .wy-dropdown>a img.logo {
  width: 10rem
}

.wy-side-nav-search {
  background-color: #1a1a1a;
}

.wy-side-nav-search>div.version {
  display: none;
}

.wy-menu-vertical header,
.wy-menu-vertical p.caption {
  color: #D67548;
}

.wy-menu-vertical li.on a,
.wy-menu-vertical li.current>a {
  background: #303030;
  border-top: none;
  border-bottom: none;
}


.wy-menu-vertical ul,
.wy-side-scroll {
  background-color: #1a1a1a;
}

.wy-menu-vertical li.toctree-l2.current>a,
.wy-menu-vertical li.toctree-l2.current li.toctree-l3>a,
.wy-menu-vertical li.toctree-l3.current li.toctree-l4>a,
.wy-menu-vertical li ul {
  background-color: #303030;
}

/* Mobile */

.wy-nav-top {
  background: #1a1a1a;
}

.wy-nav-top a {
  color: #ECB172;
}

.wy-nav-top i {
  color: #ECB172;
}

.wy-breadcrumbs {
  display: none;
}
